' ********** Copyright 2016 Roku Corp.  All Rights Reserved. **********

'A stitched Ads integration Example:
' - Include RAF.
' - setAdURL to set the ad URL.
' - getAds for VAST parsing.
' - stitchedAdsInit to import ad metadata for server-stitched ads.
' - stitchedAdHandledEvent to determines if a stitched ad is being rendered and returns metadata about the ad, after handling the event.
'@param videoContent [AA] object that has valid data for playing video with roVideoScreen.

Sub TestMixedStitchedAds(videoContent as Object)
    PlayStitchedContentWithAds(videoContent, "pkg:/feed/MixedStitchedAds.json")
End Sub

Sub PlayStitchedContentWithAds(videoContent as Object, feedFile as String)
' For stitched streams, any "loading" UI may/will be superseded by preroll ad renderer, so must take care to remove canvas early
    canvas = CreateObject("roImageCanvas")
    canvas.SetLayer(1, {color: "#000000"}) ' black canvas to mask initial video startup
    canvas.SetLayer(2, {text: Roku_Ads_util_tr("Loading...")})
    canvas.Show()

    'RAF initialize
    adIface = Roku_Ads()
    ' for debug purposes
    adIface.setDebugOutput(true)
    
    ' Get adPods array. Normally, we would set publisher's ad URL using setAdUrl and get adPods from getAds function.
    ' adIface.setAdUrl(videoContent.adUrl) 
    ' adPods = adIface.getAds()
    adPods = GetAdPods(feedFile)
    
    'Imports adPods array with server-stitched ads
    adIface.stitchedAdsInit(adPods)

    videoPlayer = PlayStitchedVideoContent(videoContent)

    playContent = true
    while playContent 
        videoMsg = wait(500, videoPlayer.GetMessagePort())

        ' check if we're rendering a stitched ad which handles the event
        curAd = adIface.stitchedAdHandledEvent(videoMsg, videoPlayer)
 
        if curAd <> invalid and curAd.evtHandled  ' ad handled event
            if curAd.adExited
                print "User exited ad view, returning to content selection"
                playContent = false
            end if
        else ' no current ad or ad did not handle event, fall through to default event handling
            if type(videoMsg) = "roVideoPlayerEvent"
                if videoMsg.isStreamStarted()
                    canvas.ClearLayer(2) ' clear buffering screen
                    canvas.SetLayer(1, [{color: "#00000000", CompositionMode: "Source"}])
                    canvas.Show()
                end if
                if videoMsg.isStatusMessage()
                    status = videoMsg.GetMessage()
                    if status = "playback stopped" or status = "end of playlist" or status = "end of stream" ' roVideoPlayer sends this message last for all exit conditions
                        playContent = false
                    end if
                end if
            end if ' videoMsg type
        end if
    end while
    if type(videoPlayer) = "roVideoPlayer" then videoPlayer.Stop()
End Sub

Function PlayStitchedVideoContent(content as Object) as Object
    videoPlayer = CreateObject("roVideoPlayer")
    videoPlayer.AddContent(content)
    videoPlayer.SetPositionNotificationPeriod(1)
    videoPlayer.SetMessagePort(CreateObject("roMessagePort"))
    screen = CreateObject("roDeviceInfo").GetDisplaySize()
    videoPlayer.Play()
    videoPlayer.SetDestinationRect(0, 0, screen.w, screen.h)

    return videoPlayer
End Function

Function GetAdPods(feedFile as String) as Object

    feed = ReadAsciiFile(feedFile)
    result = ParseJson(feed)
    
    if type(result) <> "roArray"
        return []
    end if
    
    return result
End Function